@@ -23,7 +23,7 @@ our $VERSION; # see POD
 
 BEGIN {
 	# Set our version to be the relevant $TK::Wizard::VERSION
-	$VERSION = do { my @r = ( q$Revision: 2.082 $ =~ /\d+/g ); sprintf "%d." . "%03d" x $#r, @r };
+	$VERSION = do { my @r = ( q$Revision: 2.084 $ =~ /\d+/g ); sprintf "%d." . "%03d" x $#r, @r };
 
 	# Require the correct version
 	use lib "../lib";
@@ -47,12 +47,14 @@ BEGIN {
 		Log::Log4perl->import(":easy");
 
 		if (not Log::Log4perl::initialized()){
+			my $log_conf;
 			# my ($fn) = $0 =~ /[^\/]+$/;
 
-			my $log_conf = "log4perl.logger                   		= ERROR, Screen\n";
+			$log_conf = "log4perl.logger                   		= ERROR, Screen\n";
 			#  $log_conf.= "log4perl.logger.Tk.Wizard.Installer		= ALL, Screen
 			#  		        log4perl.additivity.Tk.Wizard.Installer	= 0\n";
 
+
 			if ($Log::Log4Perl::VERSION >= 1.11){
 				$log_conf .= "log4perl.appender.Screen       	= Log::Log4perl::Appender::ScreenColoredLevels\n";
 				$log_conf .= "log4perl.appender.Screen.layout	= PatternLayout::Multiline\n";
